@@ -14,6 +14,15 @@ sub number {
     return 1;
 }
 
+sub float {
+    my ( $value, $options, $req ) = @_;
+
+    if ( $value !~ /^[0-9]+(?:\.[0-9]+)?$/ ) {
+        return 0;
+    }
+    return 1;
+}
+
 
 
 1;
